.. AutoWISP documentation master file, created by
   sphinx-quickstart on Fri Apr 27 14:33:27 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

************************************
Welcome to AutoWISP's documentation!
************************************

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    installation
    test_data
    processing_steps
    wisp_options
    implementation/autowisp

..    PythonModules/contents

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
